@@ -617,6 +617,10 @@ def show_omega_interactif_v2(omega, lam=1.085, refl=True, lam_unit='m', data=Non
     **kwargs:
         Optional arguments for the plt.pcolormesh() function.
     """
+    if omega.point_mode != 'NADIR':
+        print("\033[1m\nWarning: The pointing mode of this cube is not NADIR, "
+         + "thus it may be a better idea to use a non-projected display "
+         + "(e.g., show_omega_interactif()).\033[0m")
     # Initialisation
     if refl:
         yaxis = 'Reflectance'
